@@ -7,9 +7,10 @@ broadcasting localtime periodically.
 from __future__ import annotations
 
 import asyncio
+from collections.abc import Iterator
 from functools import partial
 import time
-from typing import TYPE_CHECKING, Iterator
+from typing import TYPE_CHECKING
 
 from xknx.core import Task
 from xknx.remote_value import GroupAddressesType, RemoteValueDateTime
