@@ -9,9 +9,7 @@ from .exception import (
     CouldNotParseTelegram,
     DeviceIllegalValue,
     IncompleteKNXIPFrame,
-    InterfaceWithUserIdNotFound,
     InvalidSecureConfiguration,
-    InvalidSignature,
     KNXSecureValidationError,
     ManagementConnectionError,
     ManagementConnectionRefused,
@@ -34,9 +32,7 @@ __all__ = [
     "ManagementConnectionRefused",
     "ManagementConnectionTimeout",
     "IncompleteKNXIPFrame",
-    "InterfaceWithUserIdNotFound",
     "InvalidSecureConfiguration",
-    "InvalidSignature",
     "KNXSecureValidationError",
     "SecureException",
     "TunnellingAckError",
